Class: Google::Cloud::LicenseManager::V1::AggregateUsageResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/licensemanager/v1/licensemanager.rb

Overview

Message for response for aggregating usage count

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token identifying a page of results the server should return.

Returns:

  • (::String)

    A token identifying a page of results the server should return.



315
316
317
318
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 315

class AggregateUsageResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Locations that could not be reached.

Returns:

  • (::Array<::String>)

    Locations that could not be reached.



315
316
317
318
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 315

class AggregateUsageResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#usages::Array<::Google::Cloud::LicenseManager::V1::Usage>

Returns The aggregated records of usage per configuration.

Returns:



315
316
317
318
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 315

class AggregateUsageResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end