Class: Google::Cloud::LicenseManager::V1::ListConfigurationsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::LicenseManager::V1::ListConfigurationsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/licensemanager/v1/licensemanager.rb
Overview
Message for response to listing Configurations
Instance Attribute Summary collapse
-
#configurations ⇒ ::Array<::Google::Cloud::LicenseManager::V1::Configuration>
The list of Configuration.
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#unreachable ⇒ ::Array<::String>
Locations that could not be reached.
Instance Attribute Details
#configurations ⇒ ::Array<::Google::Cloud::LicenseManager::V1::Configuration>
Returns The list of Configuration.
56 57 58 59 |
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 56 class ListConfigurationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
56 57 58 59 |
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 56 class ListConfigurationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Locations that could not be reached.
56 57 58 59 |
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 56 class ListConfigurationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |