Class: Google::Cloud::LicenseManager::V1::QueryConfigurationLicenseUsageRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/licensemanager/v1/licensemanager.rb

Overview

Message for requesting license usage per configuration.

Instance Attribute Summary collapse

Instance Attribute Details

#end_time::Google::Protobuf::Timestamp

Returns Required. The end time for retrieving the usage. If not specified, we will use the last day of the current billing period.

Returns:

  • (::Google::Protobuf::Timestamp)

    Required. The end time for retrieving the usage. If not specified, we will use the last day of the current billing period.



213
214
215
216
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 213

class QueryConfigurationLicenseUsageRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The resource path of the Configuration.

Returns:

  • (::String)

    Required. The resource path of the Configuration.



213
214
215
216
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 213

class QueryConfigurationLicenseUsageRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_time::Google::Protobuf::Timestamp

Returns Required. The start time for retrieving the usage. If not specified, we will use the first day of the current billing period.

Returns:

  • (::Google::Protobuf::Timestamp)

    Required. The start time for retrieving the usage. If not specified, we will use the first day of the current billing period.



213
214
215
216
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 213

class QueryConfigurationLicenseUsageRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end