Class: Google::Cloud::LicenseManager::V1::AggregateUsageRequest
- Inherits:
-
Object
- Object
- Google::Cloud::LicenseManager::V1::AggregateUsageRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/licensemanager/v1/licensemanager.rb
Overview
Message for requesting aggregate of Usage per configuration.
Instance Attribute Summary collapse
-
#end_time ⇒ ::Google::Protobuf::Timestamp
Required.
-
#filter ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
-
#order_by ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
Required.
Instance Attribute Details
#end_time ⇒ ::Google::Protobuf::Timestamp
Returns Required. Usage track is always for a month. This parameter is for the end time of the month.
300 301 302 303 |
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 300 class AggregateUsageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#filter ⇒ ::String
Returns Optional. Filtering results.
300 301 302 303 |
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 300 class AggregateUsageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. Parent value for AggregateUsageRequest.
300 301 302 303 |
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 300 class AggregateUsageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns Optional. Hint for how to order the results.
300 301 302 303 |
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 300 class AggregateUsageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.
300 301 302 303 |
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 300 class AggregateUsageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A token identifying a page of results the server should return.
300 301 302 303 |
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 300 class AggregateUsageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time ⇒ ::Google::Protobuf::Timestamp
Returns Required. Licenses are purchased per month - so usage track needs start time of a month.
300 301 302 303 |
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 300 class AggregateUsageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |