Class: Google::Cloud::LicenseManager::V1::Instance
- Inherits:
-
Object
- Object
- Google::Cloud::LicenseManager::V1::Instance
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/licensemanager/v1/api_entities.rb
Overview
Message describing Instance object
Defined Under Namespace
Modules: State Classes: LabelsEntry, ProductActivationEntry
Instance Attribute Summary collapse
-
#compute_instance ⇒ ::String
Required.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#license_version_id ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#product_activation ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::LicenseManager::V1::ActivationState}
readonly
Output only.
-
#region ⇒ ::String
readonly
Output only.
-
#state ⇒ ::Google::Cloud::LicenseManager::V1::Instance::State
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#compute_instance ⇒ ::String
Returns Required. Compute Instance resource name, i.e. projects/{project}/zones/{zone}/instances/{instance}.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'proto_docs/google/cloud/licensemanager/v1/api_entities.rb', line 194 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::LicenseManager::V1::ActivationState] class ProductActivationEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VM status enum. module State # The Status of the VM is unspecified. STATE_UNSPECIFIED = 0 # Resources are being allocated for the instance. PROVISIONING = 1 # All required resources have been allocated and # the instance is being started. STAGING = 2 # The instance is running. RUNNING = 3 # The instance is currently stopping (either being deleted or terminated). STOPPING = 4 # The instance has stopped due to various reasons (user request, VM # preemption, project freezing, etc.). STOPPED = 5 # The instance has failed in some way. TERMINATED = 6 # The instance is in repair. REPAIRING = 7 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. [Output only] Create time stamp.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'proto_docs/google/cloud/licensemanager/v1/api_entities.rb', line 194 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::LicenseManager::V1::ActivationState] class ProductActivationEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VM status enum. module State # The Status of the VM is unspecified. STATE_UNSPECIFIED = 0 # Resources are being allocated for the instance. PROVISIONING = 1 # All required resources have been allocated and # the instance is being started. STAGING = 2 # The instance is running. RUNNING = 3 # The instance is currently stopping (either being deleted or terminated). STOPPING = 4 # The instance has stopped due to various reasons (user request, VM # preemption, project freezing, etc.). STOPPED = 5 # The instance has failed in some way. TERMINATED = 6 # The instance is in repair. REPAIRING = 7 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels as key value pairs.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'proto_docs/google/cloud/licensemanager/v1/api_entities.rb', line 194 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::LicenseManager::V1::ActivationState] class ProductActivationEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VM status enum. module State # The Status of the VM is unspecified. STATE_UNSPECIFIED = 0 # Resources are being allocated for the instance. PROVISIONING = 1 # All required resources have been allocated and # the instance is being started. STAGING = 2 # The instance is running. RUNNING = 3 # The instance is currently stopping (either being deleted or terminated). STOPPING = 4 # The instance has stopped due to various reasons (user request, VM # preemption, project freezing, etc.). STOPPED = 5 # The instance has failed in some way. TERMINATED = 6 # The instance is in repair. REPAIRING = 7 end end |
#license_version_id ⇒ ::String (readonly)
Returns Output only. license version id.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'proto_docs/google/cloud/licensemanager/v1/api_entities.rb', line 194 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::LicenseManager::V1::ActivationState] class ProductActivationEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VM status enum. module State # The Status of the VM is unspecified. STATE_UNSPECIFIED = 0 # Resources are being allocated for the instance. PROVISIONING = 1 # All required resources have been allocated and # the instance is being started. STAGING = 2 # The instance is running. RUNNING = 3 # The instance is currently stopping (either being deleted or terminated). STOPPING = 4 # The instance has stopped due to various reasons (user request, VM # preemption, project freezing, etc.). STOPPED = 5 # The instance has failed in some way. TERMINATED = 6 # The instance is in repair. REPAIRING = 7 end end |
#name ⇒ ::String
Returns Identifier. name of resource.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'proto_docs/google/cloud/licensemanager/v1/api_entities.rb', line 194 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::LicenseManager::V1::ActivationState] class ProductActivationEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VM status enum. module State # The Status of the VM is unspecified. STATE_UNSPECIFIED = 0 # Resources are being allocated for the instance. PROVISIONING = 1 # All required resources have been allocated and # the instance is being started. STAGING = 2 # The instance is running. RUNNING = 3 # The instance is currently stopping (either being deleted or terminated). STOPPING = 4 # The instance has stopped due to various reasons (user request, VM # preemption, project freezing, etc.). STOPPED = 5 # The instance has failed in some way. TERMINATED = 6 # The instance is in repair. REPAIRING = 7 end end |
#product_activation ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::LicenseManager::V1::ActivationState} (readonly)
Returns Output only. Map with Product_Name and Activation State of the VM.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'proto_docs/google/cloud/licensemanager/v1/api_entities.rb', line 194 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::LicenseManager::V1::ActivationState] class ProductActivationEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VM status enum. module State # The Status of the VM is unspecified. STATE_UNSPECIFIED = 0 # Resources are being allocated for the instance. PROVISIONING = 1 # All required resources have been allocated and # the instance is being started. STAGING = 2 # The instance is running. RUNNING = 3 # The instance is currently stopping (either being deleted or terminated). STOPPING = 4 # The instance has stopped due to various reasons (user request, VM # preemption, project freezing, etc.). STOPPED = 5 # The instance has failed in some way. TERMINATED = 6 # The instance is in repair. REPAIRING = 7 end end |
#region ⇒ ::String (readonly)
Returns Output only. The location of the VM.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'proto_docs/google/cloud/licensemanager/v1/api_entities.rb', line 194 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::LicenseManager::V1::ActivationState] class ProductActivationEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VM status enum. module State # The Status of the VM is unspecified. STATE_UNSPECIFIED = 0 # Resources are being allocated for the instance. PROVISIONING = 1 # All required resources have been allocated and # the instance is being started. STAGING = 2 # The instance is running. RUNNING = 3 # The instance is currently stopping (either being deleted or terminated). STOPPING = 4 # The instance has stopped due to various reasons (user request, VM # preemption, project freezing, etc.). STOPPED = 5 # The instance has failed in some way. TERMINATED = 6 # The instance is in repair. REPAIRING = 7 end end |
#state ⇒ ::Google::Cloud::LicenseManager::V1::Instance::State (readonly)
Returns Output only. The state of the VM.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'proto_docs/google/cloud/licensemanager/v1/api_entities.rb', line 194 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::LicenseManager::V1::ActivationState] class ProductActivationEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VM status enum. module State # The Status of the VM is unspecified. STATE_UNSPECIFIED = 0 # Resources are being allocated for the instance. PROVISIONING = 1 # All required resources have been allocated and # the instance is being started. STAGING = 2 # The instance is running. RUNNING = 3 # The instance is currently stopping (either being deleted or terminated). STOPPING = 4 # The instance has stopped due to various reasons (user request, VM # preemption, project freezing, etc.). STOPPED = 5 # The instance has failed in some way. TERMINATED = 6 # The instance is in repair. REPAIRING = 7 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. [Output only] Update time stamp.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'proto_docs/google/cloud/licensemanager/v1/api_entities.rb', line 194 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::LicenseManager::V1::ActivationState] class ProductActivationEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VM status enum. module State # The Status of the VM is unspecified. STATE_UNSPECIFIED = 0 # Resources are being allocated for the instance. PROVISIONING = 1 # All required resources have been allocated and # the instance is being started. STAGING = 2 # The instance is running. RUNNING = 3 # The instance is currently stopping (either being deleted or terminated). STOPPING = 4 # The instance has stopped due to various reasons (user request, VM # preemption, project freezing, etc.). STOPPED = 5 # The instance has failed in some way. TERMINATED = 6 # The instance is in repair. REPAIRING = 7 end end |