Module: Google::Cloud::LicenseManager::V1::Instance::State
- Defined in:
- proto_docs/google/cloud/licensemanager/v1/api_entities.rb
Overview
VM status enum.
Constant Summary collapse
- STATE_UNSPECIFIED =
The Status of the VM is unspecified.
0- PROVISIONING =
Resources are being allocated for the instance.
1- STAGING =
All required resources have been allocated and the instance is being started.
2- RUNNING =
The instance is running.
3- STOPPING =
The instance is currently stopping (either being deleted or terminated).
4- STOPPED =
The instance has stopped due to various reasons (user request, VM preemption, project freezing, etc.).
5- TERMINATED =
The instance has failed in some way.
6- REPAIRING =
The instance is in repair.
7