Class: Google::Cloud::LicenseManager::V1::Product
- Inherits:
-
Object
- Object
- Google::Cloud::LicenseManager::V1::Product
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/licensemanager/v1/api_entities.rb
Overview
Products for Google SPLA.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#description ⇒ ::String
Required.
-
#display_name ⇒ ::String
Required.
-
#name ⇒ ::String
Identifier.
-
#product_company ⇒ ::String
Required.
-
#sku ⇒ ::String
Required.
-
#state ⇒ ::Google::Cloud::LicenseManager::V1::Product::State
readonly
Output only.
-
#version ⇒ ::String
Required.
Instance Attribute Details
#description ⇒ ::String
Returns Required. Human-readable, detailed description of the Product.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/licensemanager/v1/api_entities.rb', line 142 class Product include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # State of the product. module State # The Status of the product is unknown. STATE_UNSPECIFIED = 0 # Product is under provisioning stage. STATE_PROVISIONING = 1 # Product is ok to run on instances. STATE_RUNNING = 2 # The product is about to terminate or has been announced for termination. STATE_TERMINATING = 3 # The product has been terminated. STATE_TERMINATED = 4 end end |
#display_name ⇒ ::String
Returns Required. Human-readable name of the Product.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/licensemanager/v1/api_entities.rb', line 142 class Product include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # State of the product. module State # The Status of the product is unknown. STATE_UNSPECIFIED = 0 # Product is under provisioning stage. STATE_PROVISIONING = 1 # Product is ok to run on instances. STATE_RUNNING = 2 # The product is about to terminate or has been announced for termination. STATE_TERMINATING = 3 # The product has been terminated. STATE_TERMINATED = 4 end end |
#name ⇒ ::String
Returns Identifier. Full name of the product resource. ex "projects/1/locations/us-central1/products/office-2021".
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/licensemanager/v1/api_entities.rb', line 142 class Product include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # State of the product. module State # The Status of the product is unknown. STATE_UNSPECIFIED = 0 # Product is under provisioning stage. STATE_PROVISIONING = 1 # Product is ok to run on instances. STATE_RUNNING = 2 # The product is about to terminate or has been announced for termination. STATE_TERMINATING = 3 # The product has been terminated. STATE_TERMINATED = 4 end end |
#product_company ⇒ ::String
Returns Required. Company that released the product.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/licensemanager/v1/api_entities.rb', line 142 class Product include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # State of the product. module State # The Status of the product is unknown. STATE_UNSPECIFIED = 0 # Product is under provisioning stage. STATE_PROVISIONING = 1 # Product is ok to run on instances. STATE_RUNNING = 2 # The product is about to terminate or has been announced for termination. STATE_TERMINATING = 3 # The product has been terminated. STATE_TERMINATED = 4 end end |
#sku ⇒ ::String
Returns Required. SKU for mapping to the Billing/Subscription resource.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/licensemanager/v1/api_entities.rb', line 142 class Product include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # State of the product. module State # The Status of the product is unknown. STATE_UNSPECIFIED = 0 # Product is under provisioning stage. STATE_PROVISIONING = 1 # Product is ok to run on instances. STATE_RUNNING = 2 # The product is about to terminate or has been announced for termination. STATE_TERMINATING = 3 # The product has been terminated. STATE_TERMINATED = 4 end end |
#state ⇒ ::Google::Cloud::LicenseManager::V1::Product::State (readonly)
Returns Output only. State of the product.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/licensemanager/v1/api_entities.rb', line 142 class Product include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # State of the product. module State # The Status of the product is unknown. STATE_UNSPECIFIED = 0 # Product is under provisioning stage. STATE_PROVISIONING = 1 # Product is ok to run on instances. STATE_RUNNING = 2 # The product is about to terminate or has been announced for termination. STATE_TERMINATING = 3 # The product has been terminated. STATE_TERMINATED = 4 end end |
#version ⇒ ::String
Returns Required. Version of the product.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/licensemanager/v1/api_entities.rb', line 142 class Product include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # State of the product. module State # The Status of the product is unknown. STATE_UNSPECIFIED = 0 # Product is under provisioning stage. STATE_PROVISIONING = 1 # Product is ok to run on instances. STATE_RUNNING = 2 # The product is about to terminate or has been announced for termination. STATE_TERMINATING = 3 # The product has been terminated. STATE_TERMINATED = 4 end end |