Class: Google::Cloud::LicenseManager::V1::QueryConfigurationLicenseUsageResponse
- Inherits:
-
Object
- Object
- Google::Cloud::LicenseManager::V1::QueryConfigurationLicenseUsageResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/licensemanager/v1/licensemanager.rb
Overview
Message for response to get the license usage per configuration.
Instance Attribute Summary collapse
-
#user_count_usage ⇒ ::Google::Cloud::LicenseManager::V1::UserCountUsage
Usage information for license types which use user-count billing.
Instance Attribute Details
#user_count_usage ⇒ ::Google::Cloud::LicenseManager::V1::UserCountUsage
Returns Usage information for license types which use user-count billing.
222 223 224 225 |
# File 'proto_docs/google/cloud/licensemanager/v1/licensemanager.rb', line 222 class QueryConfigurationLicenseUsageResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |